# HardHat Gas Report Diff

A Python package that processes reports generated by [hardhat-gas-reporter](https://github.com/cgewecke/hardhat-gas-reporter) and generates a Markdown table comparing the two.

## Usage

1. Have `hardhat-gas-reporter` installed in your environment
2. Run `hardhat test` and save the report in a file called `before.txt`
3. Make any changes to the source code you're testing
4. Run `hardhat test` again and save the new report in a file called `after.txt`
5. Run `python -m hhgrdiff before.txt after.txt`
6. It should output a Markdown table comparing the two reports

## Help

Run `python -m hhgrdiff --help`
